==> kmyfirewall_0.9.6.2.orig.tar.gz: kmyfirewall-0.9.6.2/kmyfirewall/ipteditor/kmfnewchaindlg.h <==
/***************************************************************************
                       kmfnewchaindlg.h  -  description
                          -------------------
 begin                : Sat Mar 9 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : a9806056@unet.univie.ac.at
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFNEWCHAINDLG_H
#define KMFNEWCHAINDLG_H

#include <qwidget.h>
#include <qstringlist.h>
#include <kmyfirewallchaineditornewchain.h>

/**
  *@author Christian Hubinger
  */

class KMFDoc;

class KMFNewChainDlg : public KMyFirewallChainEditorNewChain {
	Q_OBJECT
public:
	KMFNewChainDlg( QWidget *parent = 0, const char *name = 0, bool modal = FALSE, WFlags fl = 0 );
	~KMFNewChainDlg();

	void loadDoc( KMFDoc* doc );

public slots:    // Public slots
	/** No descriptions */
	void accept();

private:
	KMFDoc* kmfdoc;

signals:
	void documentChanged( KMFDoc* );

};

#endif

==> kmyfirewall_1.1.1.orig.tar.gz: kmyfirewall-1.1.1/kmyfirewall/ipteditor/kmfnewchaindlg.h <==
/***************************************************************************
 begin                : Sat Mar 9 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : chubinger@irrsinnig.org
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFNEWCHAINDLG_H
#define KMFNEWCHAINDLG_H

#include <qwidget.h>
#include <qstringlist.h>
#include "kmyfirewallchaineditornewchain.h"
#include <qevent.h>
/**
  *@author Christian Hubinger
  */


namespace KMF {
class KMFIPTDoc;
class KMFError;
class KMFErrorHandler;
class KMFCheckInput;

class KMFNewChainDlg : public KMyFirewallChainEditorNewChain {
	Q_OBJECT
public:
	KMFNewChainDlg( QWidget *parent = 0, const char *name = 0, bool modal = FALSE, WFlags fl = 0 );
	~KMFNewChainDlg();
	void loadDoc( KMFIPTDoc* doc );

public slots:    // Public slots
	/** No descriptions */
	void accept();

private:
	KMFIPTDoc* kmfdoc;
	KMFError* m_err;
	KMFErrorHandler* m_err_handler;
	KMFCheckInput* m_check_input;

protected:
	virtual void keyPressEvent ( QKeyEvent * e );


signals:
	void sigUpdateView();

};
}
#endif
